@@ -11,6 +11,7 @@
 #' path1d <- save_history(flea[, 1:6], grand_tour(1), 10)
 #' path2d <- save_history(flea[, 1:6], grand_tour(2), 10)
 #'
+#' if (require("ggplot2")) {
 #' plot(path_curves(path1d))
 #' plot(path_curves(interpolate(path1d)))
 #'
@@ -26,6 +27,7 @@
 #' qplot(`1`, `2`, data = cast(df, ... ~ var)) + 
 #'   facet_wrap( ~ step) + 
 #'   coord_equal()
+#' }
 path_curves <- function(history, data = attr(history, "data")) {
   history <- as.list(history)
   n <- length(history)
@@ -58,7 +60,9 @@ path_curves <- function(history, data = attr(history, "data")) {
 #' @method plot path_curve
 #' @S3method plot path_curve
 plot.path_curve <- function(x, ...) {
-  ggplot2::qplot(step, value, data = x, group = obs, geom = "line") + 
+  require("ggplot2")
+  
+  qplot(step, value, data = x, group = obs, geom = "line") + 
     facet_grid(var ~ .) 
 }
 
